@@ -13,9 +13,9 @@ function(stat)
 	margin.y=1.5*max(e.f,o.f)
 	actual_cog=stat$plot$actual_cog
 	
-	sorted.cog=stat$hyper[,1][stat$hyper[,2]<0.05]
-	sorted.pval=stat$hyper[,2][stat$hyper[,2]<0.05]
-	actual_cog=stat$plot$actual_cog[stat$hyper[,2]<0.05]
+	sorted.cog=stat$hyper[,1][stat$hyper[,3]<0.1]
+	sorted.pval=stat$hyper[,3][stat$hyper[,3]<0.1]  #Adjusted P-value
+	actual_cog=stat$plot$actual_cog[stat$hyper[,3]<0.1]
 	n=length(actual_cog)
 	ecount=rep(0,n)
 	ocount=rep(0,n)
@@ -28,14 +28,23 @@ function(stat)
 	for(i in 1:n){
 		o=values(h,key=sorted.cog[i],USE.NAMES=FALSE)
 		e=values(h_ref,key=sorted.cog[i],USE.NAMES=FALSE)
-		plotmat[1,i]= o #o/o.total*100
+		plotmat[1,i]= o 
 		plotmat[2,i]= round(e/e.total*o.total,digits=0)
 		ocount[i]=o
 		ecount[i]=round(e/e.total*o.total,digits=0)
 		ototal[i]=o.total
 		etotal[i]=e.total
 	}	
+	label=vector()
+	for(i in 1:length(sorted.cog)){
+		v1=sorted.pval[i]
+		if(v1<0.00001){
+			v=paste(sorted.cog[i]," (adj p < 0.00001)\n","o=",ocount[i]," e=",ecount[i],sep="")
+		}else{
+			v=paste(sorted.cog[i]," (adj p =",round(sorted.pval[i],digits=5),")\n","o=",ocount[i]," e=",ecount[i],sep="")
+		}
+		label=append(label,v)
+	}
 	
-	label=paste(sorted.cog,"(",round(sorted.pval,digits=5),")\n","o=",ocount,"e=",ecount)
 	list(plotmat=plotmat,label=label,margin.y=margin.y,e.total=e.total,o.total=o.total)
 }
